validate_with_dialect

Function validate_with_dialect 

pub fn validate_with_dialect(
    sql: &str,
    dialect: &Dialect,
    options: &ValidationOptions,
) -> ValidationResult
Validate SQL using an already-resolved dialect.

This is useful for wrappers and custom dialect consumers that should retain the exact tokenizer and parser configuration of a Dialect handle.