pub fn output_columns_with_schema(
sql: &Expression,
schema: Option<&dyn Schema>,
dialect: Option<DialectType>,
) -> Result<QueryOutput>Expand description
Return the ordered output description of a query after schema-aware expansion.
pub fn output_columns_with_schema(
sql: &Expression,
schema: Option<&dyn Schema>,
dialect: Option<DialectType>,
) -> Result<QueryOutput>Return the ordered output description of a query after schema-aware expansion.