OptimizationRule

Enum OptimizationRule 

pub enum OptimizationRule {
Show 14 variants Qualify, PushdownProjections, Normalize, UnnestSubqueries, PushdownPredicates, OptimizeJoins, EliminateSubqueries, MergeSubqueries, EliminateJoins, EliminateCtes, QuoteIdentifiers, AnnotateTypes, Canonicalize, Simplify,
}
Optimization rule type

Variants



Qualify

Qualify columns and tables with their full names



PushdownProjections

Push projections down to eliminate unused columns early



Normalize

Normalize boolean expressions



UnnestSubqueries

Unnest correlated subqueries into joins



PushdownPredicates

Push predicates down to filter data early



OptimizeJoins

Optimize join order and remove cross joins



EliminateSubqueries

Eliminate derived tables by converting to CTEs



MergeSubqueries

Merge subqueries into outer queries



EliminateJoins

Eliminate unused joins after join optimization and subquery merges



EliminateCtes

Remove unused CTEs



QuoteIdentifiers

Quote identifiers that require quoting for the target dialect



AnnotateTypes

Annotate expressions with type information



Canonicalize

Convert expressions to canonical form



Simplify

Simplify expressions