pub fn strip_cte_materialization(expr: Expression) -> Result<Expression>Expand description
Strip PostgreSQL CTE materialization hints for targets that do not support
AS MATERIALIZED / AS NOT MATERIALIZED.
pub fn strip_cte_materialization(expr: Expression) -> Result<Expression>Strip PostgreSQL CTE materialization hints for targets that do not support
AS MATERIALIZED / AS NOT MATERIALIZED.