get_merge_source

Function get_merge_source 

pub fn get_merge_source(expr: &Expression) -> Option<&Expression>
Returns the source table of a MERGE statement (the Merge.using field), unwrapping any alias wrapper to yield the underlying Expression::Table.

Returns None if expr is not a Merge, the source isn’t a recognisable table (e.g. it’s a subquery), or the source is otherwise unresolvable.