pub fn validate_with_dialect(
sql: &str,
dialect: &Dialect,
options: &ValidationOptions,
) -> ValidationResultExpand description
Validate SQL using an already-resolved dialect.
This is useful for wrappers and custom dialect consumers that should retain
the exact tokenizer and parser configuration of a Dialect handle.