#[repr(u16)]pub enum TokenType {
Show 534 variants
LParen = 0,
RParen = 1,
LBracket = 2,
RBracket = 3,
LBrace = 4,
RBrace = 5,
Comma = 6,
Dot = 7,
Dash = 8,
Plus = 9,
Colon = 10,
DotColon = 11,
DColon = 12,
DColonDollar = 13,
DColonPercent = 14,
DColonQMark = 15,
DQMark = 16,
Semicolon = 17,
Star = 18,
Backslash = 19,
Slash = 20,
Lt = 21,
Lte = 22,
Gt = 23,
Gte = 24,
Not = 25,
Eq = 26,
Neq = 27,
NullsafeEq = 28,
ColonEq = 29,
ColonGt = 30,
NColonGt = 31,
And = 32,
Or = 33,
Amp = 34,
DPipe = 35,
PipeGt = 36,
Pipe = 37,
PipeSlash = 38,
DPipeSlash = 39,
Caret = 40,
CaretAt = 41,
LtLt = 42,
GtGt = 43,
Tilde = 44,
Arrow = 45,
DArrow = 46,
FArrow = 47,
Hash = 48,
HashArrow = 49,
DHashArrow = 50,
LrArrow = 51,
DAt = 52,
AtAt = 53,
AtQMark = 54,
LtAt = 55,
AtGt = 56,
Dollar = 57,
Parameter = 58,
Session = 59,
SessionParameter = 60,
SessionUser = 61,
DAmp = 62,
AmpLt = 63,
AmpGt = 64,
Adjacent = 65,
Xor = 66,
DStar = 67,
QMarkAmp = 68,
QMarkPipe = 69,
HashDash = 70,
Exclamation = 71,
UriStart = 72,
BlockStart = 73,
BlockEnd = 74,
Space = 75,
Break = 76,
BlockComment = 77,
LineComment = 78,
String = 79,
DollarString = 80,
TripleDoubleQuotedString = 81,
TripleSingleQuotedString = 82,
Number = 83,
Identifier = 84,
QuotedIdentifier = 85,
Database = 86,
Column = 87,
ColumnDef = 88,
Schema = 89,
Table = 90,
Warehouse = 91,
Stage = 92,
Streamlit = 93,
Var = 94,
BitString = 95,
HexString = 96,
HexNumber = 97,
ByteString = 98,
NationalString = 99,
EscapeString = 100,
RawString = 101,
HeredocString = 102,
HeredocStringAlternative = 103,
UnicodeString = 104,
Bit = 105,
Boolean = 106,
TinyInt = 107,
UTinyInt = 108,
SmallInt = 109,
USmallInt = 110,
MediumInt = 111,
UMediumInt = 112,
Int = 113,
UInt = 114,
BigInt = 115,
UBigInt = 116,
BigNum = 117,
Int128 = 118,
UInt128 = 119,
Int256 = 120,
UInt256 = 121,
Float = 122,
Double = 123,
UDouble = 124,
Decimal = 125,
Decimal32 = 126,
Decimal64 = 127,
Decimal128 = 128,
Decimal256 = 129,
DecFloat = 130,
UDecimal = 131,
BigDecimal = 132,
Char = 133,
NChar = 134,
VarChar = 135,
NVarChar = 136,
BpChar = 137,
Text = 138,
MediumText = 139,
LongText = 140,
Blob = 141,
MediumBlob = 142,
LongBlob = 143,
TinyBlob = 144,
TinyText = 145,
Name = 146,
Binary = 147,
VarBinary = 148,
Json = 149,
JsonB = 150,
Time = 151,
TimeTz = 152,
TimeNs = 153,
Timestamp = 154,
TimestampTz = 155,
TimestampLtz = 156,
TimestampNtz = 157,
TimestampS = 158,
TimestampMs = 159,
TimestampNs = 160,
DateTime = 161,
DateTime2 = 162,
DateTime64 = 163,
SmallDateTime = 164,
Date = 165,
Date32 = 166,
Int4Range = 167,
Int4MultiRange = 168,
Int8Range = 169,
Int8MultiRange = 170,
NumRange = 171,
NumMultiRange = 172,
TsRange = 173,
TsMultiRange = 174,
TsTzRange = 175,
TsTzMultiRange = 176,
DateRange = 177,
DateMultiRange = 178,
Uuid = 179,
Geography = 180,
GeographyPoint = 181,
Nullable = 182,
Geometry = 183,
Point = 184,
Ring = 185,
LineString = 186,
LocalTime = 187,
LocalTimestamp = 188,
SysTimestamp = 189,
MultiLineString = 190,
Polygon = 191,
MultiPolygon = 192,
HllSketch = 193,
HStore = 194,
Super = 195,
Serial = 196,
SmallSerial = 197,
BigSerial = 198,
Xml = 199,
Year = 200,
UserDefined = 201,
Money = 202,
SmallMoney = 203,
RowVersion = 204,
Image = 205,
Variant = 206,
Object = 207,
Inet = 208,
IpAddress = 209,
IpPrefix = 210,
Ipv4 = 211,
Ipv6 = 212,
Enum = 213,
Enum8 = 214,
Enum16 = 215,
FixedString = 216,
LowCardinality = 217,
Nested = 218,
AggregateFunction = 219,
SimpleAggregateFunction = 220,
TDigest = 221,
Unknown = 222,
Vector = 223,
Dynamic = 224,
Void = 225,
Add = 226,
Alias = 227,
Alter = 228,
All = 229,
Anti = 230,
Any = 231,
Apply = 232,
Array = 233,
Asc = 234,
AsOf = 235,
Attach = 236,
AutoIncrement = 237,
Begin = 238,
Between = 239,
BulkCollectInto = 240,
Cache = 241,
Cascade = 242,
Case = 243,
CharacterSet = 244,
Cluster = 245,
ClusterBy = 246,
Collate = 247,
Command = 248,
Comment = 249,
Commit = 250,
Prepare = 251,
Preserve = 252,
Connect = 253,
ConnectBy = 254,
Constraint = 255,
Copy = 256,
Create = 257,
Cross = 258,
Cube = 259,
CurrentDate = 260,
CurrentDateTime = 261,
CurrentSchema = 262,
CurrentTime = 263,
CurrentTimestamp = 264,
CurrentUser = 265,
CurrentRole = 266,
CurrentCatalog = 267,
Declare = 268,
Default = 269,
Delete = 270,
Desc = 271,
Describe = 272,
Detach = 273,
Dictionary = 274,
Distinct = 275,
Distribute = 276,
DistributeBy = 277,
Div = 278,
Drop = 279,
Else = 280,
End = 281,
Escape = 282,
Except = 283,
Execute = 284,
Exists = 285,
False = 286,
Fetch = 287,
File = 288,
FileFormat = 289,
Filter = 290,
Final = 291,
First = 292,
For = 293,
Force = 294,
ForeignKey = 295,
Format = 296,
From = 297,
Full = 298,
Function = 299,
Get = 300,
Glob = 301,
Global = 302,
Grant = 303,
GroupBy = 304,
GroupingSets = 305,
Having = 306,
Hint = 307,
Ignore = 308,
ILike = 309,
In = 310,
Index = 311,
IndexedBy = 312,
Inner = 313,
Input = 314,
Insert = 315,
Install = 316,
Intersect = 317,
Interval = 318,
Into = 319,
Inpath = 320,
InputFormat = 321,
Introducer = 322,
IRLike = 323,
Is = 324,
IsNull = 325,
Join = 326,
JoinMarker = 327,
Keep = 328,
Key = 329,
Kill = 330,
Lambda = 331,
Language = 332,
Lateral = 333,
Left = 334,
Like = 335,
NotLike = 336,
NotILike = 337,
NotRLike = 338,
NotIRLike = 339,
Limit = 340,
List = 341,
Load = 342,
Local = 343,
Lock = 344,
Map = 345,
Match = 346,
MatchCondition = 347,
MatchRecognize = 348,
MemberOf = 349,
Materialized = 350,
Merge = 351,
Mod = 352,
Model = 353,
Natural = 354,
Next = 355,
NoAction = 356,
Nothing = 357,
NotNull = 358,
Null = 359,
ObjectIdentifier = 360,
Offset = 361,
On = 362,
Only = 363,
Operator = 364,
OrderBy = 365,
OrderSiblingsBy = 366,
Ordered = 367,
Ordinality = 368,
Out = 369,
Outer = 370,
Output = 371,
Over = 372,
Overlaps = 373,
Overwrite = 374,
Partition = 375,
PartitionBy = 376,
Percent = 377,
Pivot = 378,
Placeholder = 379,
Positional = 380,
Pragma = 381,
Prewhere = 382,
PrimaryKey = 383,
Procedure = 384,
Properties = 385,
PseudoType = 386,
Put = 387,
Qualify = 388,
Quote = 389,
QDColon = 390,
Range = 391,
Recursive = 392,
Refresh = 393,
Rename = 394,
Replace = 395,
Returning = 396,
Revoke = 397,
References = 398,
Restrict = 399,
Right = 400,
RLike = 401,
Rollback = 402,
Rollup = 403,
Row = 404,
Rows = 405,
Select = 406,
Semi = 407,
Savepoint = 408,
Separator = 409,
Sequence = 410,
Serde = 411,
SerdeProperties = 412,
Set = 413,
Settings = 414,
Show = 415,
Siblings = 416,
SimilarTo = 417,
Some = 418,
Sort = 419,
SortBy = 420,
SoundsLike = 421,
StartWith = 422,
StorageIntegration = 423,
StraightJoin = 424,
Struct = 425,
Summarize = 426,
TableSample = 427,
Sample = 428,
Bernoulli = 429,
System = 430,
Block = 431,
Seed = 432,
Repeatable = 433,
Tag = 434,
Temporary = 435,
Transaction = 436,
To = 437,
Top = 438,
Then = 439,
True = 440,
Truncate = 441,
Uncache = 442,
Union = 443,
Unnest = 444,
Unpivot = 445,
Update = 446,
Use = 447,
Using = 448,
Values = 449,
View = 450,
SemanticView = 451,
Volatile = 452,
When = 453,
Where = 454,
Window = 455,
With = 456,
Ties = 457,
Exclude = 458,
No = 459,
Others = 460,
Unique = 461,
UtcDate = 462,
UtcTime = 463,
UtcTimestamp = 464,
VersionSnapshot = 465,
TimestampSnapshot = 466,
Option = 467,
Sink = 468,
Source = 469,
Analyze = 470,
Namespace = 471,
Export = 472,
As = 473,
By = 474,
Nulls = 475,
Respect = 476,
Last = 477,
If = 478,
Cast = 479,
TryCast = 480,
SafeCast = 481,
Count = 482,
Extract = 483,
Substring = 484,
Trim = 485,
Leading = 486,
Trailing = 487,
Both = 488,
Position = 489,
Overlaying = 490,
Placing = 491,
Treat = 492,
Within = 493,
Group = 494,
Order = 495,
Unbounded = 496,
Preceding = 497,
Following = 498,
Current = 499,
Groups = 500,
Trigger = 501,
Type = 502,
Domain = 503,
Returns = 504,
Body = 505,
Increment = 506,
Minvalue = 507,
Maxvalue = 508,
Start = 509,
Cycle = 510,
NoCycle = 511,
Prior = 512,
Generated = 513,
Identity = 514,
Always = 515,
Measures = 516,
Pattern = 517,
Define = 518,
Running = 519,
Owned = 520,
After = 521,
Before = 522,
Instead = 523,
Each = 524,
Statement = 525,
Referencing = 526,
Old = 527,
New = 528,
Of = 529,
Check = 530,
Authorization = 531,
Restart = 532,
Eof = 533,
}Expand description
All possible token types in SQL
Variants
LParen = 0
RParen = 1
LBracket = 2
RBracket = 3
LBrace = 4
RBrace = 5
Comma = 6
Dot = 7
Dash = 8
Plus = 9
Colon = 10
DotColon = 11
DColon = 12
DColonDollar = 13
DColonPercent = 14
DColonQMark = 15
DQMark = 16
Semicolon = 17
Star = 18
Backslash = 19
Slash = 20
Lt = 21
Lte = 22
Gt = 23
Gte = 24
Not = 25
Eq = 26
Neq = 27
NullsafeEq = 28
ColonEq = 29
ColonGt = 30
NColonGt = 31
And = 32
Or = 33
Amp = 34
DPipe = 35
PipeGt = 36
Pipe = 37
PipeSlash = 38
DPipeSlash = 39
Caret = 40
CaretAt = 41
LtLt = 42
GtGt = 43
Tilde = 44
Arrow = 45
DArrow = 46
FArrow = 47
Hash = 48
HashArrow = 49
DHashArrow = 50
LrArrow = 51
DAt = 52
AtAt = 53
AtQMark = 54
LtAt = 55
AtGt = 56
Dollar = 57
Parameter = 58
Session = 59
SessionParameter = 60
SessionUser = 61
DAmp = 62
AmpLt = 63
AmpGt = 64
Adjacent = 65
Xor = 66
DStar = 67
QMarkAmp = 68
QMarkPipe = 69
HashDash = 70
Exclamation = 71
UriStart = 72
BlockStart = 73
BlockEnd = 74
Space = 75
Break = 76
BlockComment = 77
LineComment = 78
String = 79
DollarString = 80
TripleDoubleQuotedString = 81
TripleSingleQuotedString = 82
Number = 83
Identifier = 84
QuotedIdentifier = 85
Database = 86
Column = 87
ColumnDef = 88
Schema = 89
Table = 90
Warehouse = 91
Stage = 92
Streamlit = 93
Var = 94
BitString = 95
HexString = 96
HexNumber = 97
Hex number: 0xA, 0xFF (BigQuery, SQLite style) - represents an integer in hex notation
ByteString = 98
NationalString = 99
EscapeString = 100
RawString = 101
HeredocString = 102
HeredocStringAlternative = 103
UnicodeString = 104
Bit = 105
Boolean = 106
TinyInt = 107
UTinyInt = 108
SmallInt = 109
USmallInt = 110
MediumInt = 111
UMediumInt = 112
Int = 113
UInt = 114
BigInt = 115
UBigInt = 116
BigNum = 117
Int128 = 118
UInt128 = 119
Int256 = 120
UInt256 = 121
Float = 122
Double = 123
UDouble = 124
Decimal = 125
Decimal32 = 126
Decimal64 = 127
Decimal128 = 128
Decimal256 = 129
DecFloat = 130
UDecimal = 131
BigDecimal = 132
Char = 133
NChar = 134
VarChar = 135
NVarChar = 136
BpChar = 137
Text = 138
MediumText = 139
LongText = 140
Blob = 141
MediumBlob = 142
LongBlob = 143
TinyBlob = 144
TinyText = 145
Name = 146
Binary = 147
VarBinary = 148
Json = 149
JsonB = 150
Time = 151
TimeTz = 152
TimeNs = 153
Timestamp = 154
TimestampTz = 155
TimestampLtz = 156
TimestampNtz = 157
TimestampS = 158
TimestampMs = 159
TimestampNs = 160
DateTime = 161
DateTime2 = 162
DateTime64 = 163
SmallDateTime = 164
Date = 165
Date32 = 166
Int4Range = 167
Int4MultiRange = 168
Int8Range = 169
Int8MultiRange = 170
NumRange = 171
NumMultiRange = 172
TsRange = 173
TsMultiRange = 174
TsTzRange = 175
TsTzMultiRange = 176
DateRange = 177
DateMultiRange = 178
Uuid = 179
Geography = 180
GeographyPoint = 181
Nullable = 182
Geometry = 183
Point = 184
Ring = 185
LineString = 186
LocalTime = 187
LocalTimestamp = 188
SysTimestamp = 189
MultiLineString = 190
Polygon = 191
MultiPolygon = 192
HllSketch = 193
HStore = 194
Super = 195
Serial = 196
SmallSerial = 197
BigSerial = 198
Xml = 199
Year = 200
UserDefined = 201
Money = 202
SmallMoney = 203
RowVersion = 204
Image = 205
Variant = 206
Object = 207
Inet = 208
IpAddress = 209
IpPrefix = 210
Ipv4 = 211
Ipv6 = 212
Enum = 213
Enum8 = 214
Enum16 = 215
FixedString = 216
LowCardinality = 217
Nested = 218
AggregateFunction = 219
SimpleAggregateFunction = 220
TDigest = 221
Unknown = 222
Vector = 223
Dynamic = 224
Void = 225
Add = 226
Alias = 227
Alter = 228
All = 229
Anti = 230
Any = 231
Apply = 232
Array = 233
Asc = 234
AsOf = 235
Attach = 236
AutoIncrement = 237
Begin = 238
Between = 239
BulkCollectInto = 240
Cache = 241
Cascade = 242
Case = 243
CharacterSet = 244
Cluster = 245
ClusterBy = 246
Collate = 247
Command = 248
Comment = 249
Commit = 250
Prepare = 251
Preserve = 252
Connect = 253
ConnectBy = 254
Constraint = 255
Copy = 256
Create = 257
Cross = 258
Cube = 259
CurrentDate = 260
CurrentDateTime = 261
CurrentSchema = 262
CurrentTime = 263
CurrentTimestamp = 264
CurrentUser = 265
CurrentRole = 266
CurrentCatalog = 267
Declare = 268
Default = 269
Delete = 270
Desc = 271
Describe = 272
Detach = 273
Dictionary = 274
Distinct = 275
Distribute = 276
DistributeBy = 277
Div = 278
Drop = 279
Else = 280
End = 281
Escape = 282
Except = 283
Execute = 284
Exists = 285
False = 286
Fetch = 287
File = 288
FileFormat = 289
Filter = 290
Final = 291
First = 292
For = 293
Force = 294
ForeignKey = 295
Format = 296
From = 297
Full = 298
Function = 299
Get = 300
Glob = 301
Global = 302
Grant = 303
GroupBy = 304
GroupingSets = 305
Having = 306
Hint = 307
Ignore = 308
ILike = 309
In = 310
Index = 311
IndexedBy = 312
Inner = 313
Input = 314
Insert = 315
Install = 316
Intersect = 317
Interval = 318
Into = 319
Inpath = 320
InputFormat = 321
Introducer = 322
IRLike = 323
Is = 324
IsNull = 325
Join = 326
JoinMarker = 327
Keep = 328
Key = 329
Kill = 330
Lambda = 331
Language = 332
Lateral = 333
Left = 334
Like = 335
NotLike = 336
NotILike = 337
NotRLike = 338
NotIRLike = 339
Limit = 340
List = 341
Load = 342
Local = 343
Lock = 344
Map = 345
Match = 346
MatchCondition = 347
MatchRecognize = 348
MemberOf = 349
Materialized = 350
Merge = 351
Mod = 352
Model = 353
Natural = 354
Next = 355
NoAction = 356
Nothing = 357
NotNull = 358
Null = 359
ObjectIdentifier = 360
Offset = 361
On = 362
Only = 363
Operator = 364
OrderBy = 365
OrderSiblingsBy = 366
Ordered = 367
Ordinality = 368
Out = 369
Outer = 370
Output = 371
Over = 372
Overlaps = 373
Overwrite = 374
Partition = 375
PartitionBy = 376
Percent = 377
Pivot = 378
Placeholder = 379
Positional = 380
Pragma = 381
Prewhere = 382
PrimaryKey = 383
Procedure = 384
Properties = 385
PseudoType = 386
Put = 387
Qualify = 388
Quote = 389
QDColon = 390
Range = 391
Recursive = 392
Refresh = 393
Rename = 394
Replace = 395
Returning = 396
Revoke = 397
References = 398
Restrict = 399
Right = 400
RLike = 401
Rollback = 402
Rollup = 403
Row = 404
Rows = 405
Select = 406
Semi = 407
Savepoint = 408
Separator = 409
Sequence = 410
Serde = 411
SerdeProperties = 412
Set = 413
Settings = 414
Show = 415
Siblings = 416
SimilarTo = 417
Some = 418
Sort = 419
SortBy = 420
SoundsLike = 421
StartWith = 422
StorageIntegration = 423
StraightJoin = 424
Struct = 425
Summarize = 426
TableSample = 427
Sample = 428
Bernoulli = 429
System = 430
Block = 431
Seed = 432
Repeatable = 433
Tag = 434
Temporary = 435
Transaction = 436
To = 437
Top = 438
Then = 439
True = 440
Truncate = 441
Uncache = 442
Union = 443
Unnest = 444
Unpivot = 445
Update = 446
Use = 447
Using = 448
Values = 449
View = 450
SemanticView = 451
Volatile = 452
When = 453
Where = 454
Window = 455
With = 456
Ties = 457
Exclude = 458
No = 459
Others = 460
Unique = 461
UtcDate = 462
UtcTime = 463
UtcTimestamp = 464
VersionSnapshot = 465
TimestampSnapshot = 466
Option = 467
Sink = 468
Source = 469
Analyze = 470
Namespace = 471
Export = 472
As = 473
By = 474
Nulls = 475
Respect = 476
Last = 477
If = 478
Cast = 479
TryCast = 480
SafeCast = 481
Count = 482
Extract = 483
Substring = 484
Trim = 485
Leading = 486
Trailing = 487
Both = 488
Position = 489
Overlaying = 490
Placing = 491
Treat = 492
Within = 493
Group = 494
Order = 495
Unbounded = 496
Preceding = 497
Following = 498
Current = 499
Groups = 500
Trigger = 501
Type = 502
Domain = 503
Returns = 504
Body = 505
Increment = 506
Minvalue = 507
Maxvalue = 508
Start = 509
Cycle = 510
NoCycle = 511
Prior = 512
Generated = 513
Identity = 514
Always = 515
Measures = 516
Pattern = 517
Define = 518
Running = 519
Owned = 520
After = 521
Before = 522
Instead = 523
Each = 524
Statement = 525
Referencing = 526
Old = 527
New = 528
Of = 529
Check = 530
Authorization = 531
Restart = 532
Eof = 533
Implementations
Sourceimpl TokenType
impl TokenType
Sourcepub fn is_keyword(&self) -> bool
pub fn is_keyword(&self) -> bool
Check if this token type is a keyword that can be used as an identifier in certain contexts
Sourcepub fn is_comparison(&self) -> bool
pub fn is_comparison(&self) -> bool
Check if this token type is a comparison operator
Sourcepub fn is_arithmetic(&self) -> bool
pub fn is_arithmetic(&self) -> bool
Check if this token type is an arithmetic operator