pub fn get_merge_target(expr: &Expression) -> Option<&Expression>Expand description
Returns the target table of a MERGE statement (the Merge.this field),
unwrapping any alias wrapper to yield the underlying Expression::Table.
Returns None if expr is not a Merge or the target isn’t a recognisable table.